/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file drawprintf.h
 *
 * @type helper
 *
 * @description
 *
 * The drawprintf helper is designed to allow printf-style printing to a
 * canvas using the WIMP font. Internally it uses Wimp_PlotIcon to display
 * the text on the screen, allowing for bounding boxes to be taken into
 * consideration.
 */

#ifndef __rov_drawprintf
#define __rov_drawprintf


#ifdef __cplusplus
extern "C"
{
#endif

/**
 * Displays text.
 * @param lx left hand (canvas) x coordinate.
 * @param by bottom (canvas) y coordinate.
 * @param fcol foreground (WIMP) colour.
 * @param bcol background (WIMP) colour.
 * @param pf_str printf-style string.
 * @param ... optional parameters.
 * @note The size of the buffer is limited to 512 bytes.
 * @note The background is not filled in, and the background colour parameter
 * is only used to determine the anti-aliasing colours.
 * @see draw_printfb()
 * @see draw_printff()
 */
void draw_printf(int lx,
		 int by,
		 int fcol,
		 int bcol,
		 char *pf_str,
		 ...);

/**
 * Displays text in a fixed width format.
 * @param lx left hand (canvas) x coordinate.
 * @param rx right hand (canvas) x coordinate.
 * @param by bottom (canvas) y coordinate.
 * @param fcol foreground (WIMP) colour.
 * @param bcol background (WIMP) colour.
 * @param pf_str printf-style string.
 * @param ... optional parameters.
 * @note The size of the buffer is limited to 512 bytes.
 * @note The background is not filled in, and the background colour parameter
 * is only used to determine the anti-aliasing colours.
 * @see draw_printf()
 * @see draw_printffb()
 */
void draw_printff(int lx,
		  int rx,
		  int by,
		  int fcol,
		  int bcol,
		  char *pf_str,
		  ...);

/**
 * Displays text with a filled background.
 * @param lx left hand (canvas) x coordinate.
 * @param by bottom (canvas) y coordinate.
 * @param fcol foreground (WIMP) colour.
 * @param bcol background (WIMP) colour.
 * @param pf_str printf-style string.
 * @param ... optional parameters.
 * @note The size of the buffer is limited to 512 bytes.
 * @see draw_printf()
 * @see draw_printffb()
 */
void draw_printfb(int lx,
		  int by,
		  int fcol,
		  int bcol,
		  char *pf_str,
		  ...);

/**
 * Displays text in a fixed width format and filled background.
 * @param lx left hand (canvas) x coordinate.
 * @param rx right hand (canvas) x coordinate.
 * @param by bottom (canvas) y coordinate.
 * @param fcol foreground (WIMP) colour.
 * @param bcol background (WIMP) colour.
 * @param pf_str printf-style string.
 * @param ... optional parameters.
 * @note The size of the buffer is limited to 512 bytes.
 * @see draw_printfb()
 * @see draw_printff()
 */
void draw_printffb(int lx,
		   int rx,
		   int by,
		   int fcol,
		   int bcol,
		   char *pf_str,
		   ...);


#ifdef __cplusplus
}
#endif

#endif
